﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using SimpleBlogDAL;

namespace SimpleBlog.Controllers
{
    public class BlogController : Controller
    {
        private DatabaseEntities db = new DatabaseEntities();

        public ViewResult Index()
        {
            Session["CurrentBlog"] = null;
            var blogs = db.Blogs.Include("Theme").Include("User");
            return View(blogs.ToList());
        }

        public ViewResult Details(int id)
        {
            Blog blog = db.Blogs.Single(b => b.blog_id == id);
            return View(blog);
        }

        public ActionResult Create()
        {
            User loggedUser = (User)Session["Logged"];
            ViewBag.theme_id = new SelectList(db.Themes, "theme_id", "name");
            ViewBag.user_id = loggedUser.user_id;
            return View();
        }
        [HttpPost]
        public ActionResult Create(Blog blog)
        {
            User loggedUser = (User)Session["Logged"];
            if (ModelState.IsValid)
            {
                blog.user_id = loggedUser.user_id;
                db.Blogs.AddObject(blog);
                db.SaveChanges();
                return RedirectToAction("Index");
            }


            ViewBag.theme_id = new SelectList(db.Themes, "theme_id", "name", blog.theme_id);
            ViewBag.user_id = loggedUser.user_id;
            return View(blog);
        }

        public ActionResult Edit(int id)
        {
            User loggedUser = (User)Session["Logged"];
            Blog blog = db.Blogs.Single(b => b.blog_id == id);
            ViewBag.theme_id = new SelectList(db.Themes, "theme_id", "name", blog.theme_id);
            ViewBag.user_id = loggedUser.user_id;
            return View(blog);
        }
        [HttpPost]
        public ActionResult Edit(Blog blog)
        {
            User loggedUser = (User)Session["Logged"];
            if (ModelState.IsValid)
            {
                blog.user_id = loggedUser.user_id;
                db.Blogs.Attach(blog);
                db.ObjectStateManager.ChangeObjectState(blog, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }


            ViewBag.theme_id = new SelectList(db.Themes, "theme_id", "name", blog.theme_id);
            ViewBag.user_id = loggedUser.user_id;
            return View(blog);
        }

        public ActionResult Delete(int id)
        {
            Blog blog = db.Blogs.Single(b => b.blog_id == id);
            return View(blog);
        }
        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            Blog blog = db.Blogs.Single(b => b.blog_id == id);
            db.Blogs.DeleteObject(blog);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        public ActionResult Admin(int id)
        {
            Blog blog = db.Blogs.Single(b => b.blog_id == id);
            Session["CurrentBlog"] = blog;

            return View(blog);
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}