﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using SimpleBlogDAL;

namespace SimpleBlog.Controllers
{
    public class PostController : Controller
    {
        private DatabaseEntities db = new DatabaseEntities();

        public ViewResult Index()
        {
            var posts = db.Posts.Include("Category").Include("Page");
            return View(posts.ToList());
        }

        public ViewResult Details(int id)
        {
            Post post = db.Posts.Single(p => p.post_id == id);
            return View(post);
        }

        public ActionResult Create()
        {
            Blog blog = (Blog)Session["CurrentBlog"];
            ViewBag.category_id = new SelectList(db.Categories.Where(x=>x.blog_id == blog.blog_id) , "category_id", "name");
            ViewBag.page_id = new SelectList(db.Pages.Where(x=>x.Menu.blog_id == blog.blog_id), "page_id", "name");
            return View();
        }
        [HttpPost]
        public ActionResult Create(Post post)
        {
            if (ModelState.IsValid)
            {
                db.Posts.AddObject(post);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            ViewBag.category_id = new SelectList(db.Categories, "category_id", "name", post.category_id);
            ViewBag.page_id = new SelectList(db.Pages, "page_id", "name", post.page_id);
            return View(post);
        }

        public ActionResult Edit(int id)
        {
            Post post = db.Posts.Single(p => p.post_id == id);
            Blog blog = (Blog)Session["CurrentBlog"];
            ViewBag.category_id = new SelectList(db.Categories.Where(x => x.blog_id == blog.blog_id), "category_id", "name");
            ViewBag.page_id = new SelectList(db.Pages.Where(x => x.Menu.blog_id == blog.blog_id), "page_id", "name");
            return View(post);
        }
        [HttpPost]
        public ActionResult Edit(Post post)
        {
            if (ModelState.IsValid)
            {
                db.Posts.Attach(post);
                db.ObjectStateManager.ChangeObjectState(post, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.category_id = new SelectList(db.Categories, "category_id", "name", post.category_id);
            ViewBag.page_id = new SelectList(db.Pages, "page_id", "name", post.page_id);
            return View(post);
        }

        public ActionResult Delete(int id)
        {
            Post post = db.Posts.Single(p => p.post_id == id);
            return View(post);
        }
        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            Post post = db.Posts.Single(p => p.post_id == id);
            db.Posts.DeleteObject(post);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}